@@ -18,26 +18,24 @@ def get_default_driver_options(width=1472, height=828, headless=True) -> Options
     chrome_options.headless = headless
     chrome_options.page_load_strategy = 'normal'
 
-    chrome_options.add_argument('--enable-automation'),
-    chrome_options.add_argument('--start-maximized'),
-    chrome_options.add_argument(f'--window-size={width},{height}'),
-    chrome_options.add_argument('--lang=en-GB'),
-    chrome_options.add_argument('--no-sandbox'),
-    chrome_options.add_argument('--disable-setuid-sandbox'),
-    chrome_options.add_argument('--disable-gpu'),
-    chrome_options.add_argument('--disable-dev-shm-usage'),
-    chrome_options.add_argument('--no-sandbox'),
-    chrome_options.add_argument('--disable-setuid-sandbox'),
-    chrome_options.add_argument('--disable-dev-shm-usage'),
-    chrome_options.add_argument('--disable-accelerated-2d-canvas'),
-    chrome_options.add_argument('--disable-gpu'),
-    chrome_options.add_argument('--allow-running-insecure-content'),
-    chrome_options.add_argument('--disable-web-security'),
-    chrome_options.add_argument('--disable-client-side-phishing-detection'),
-    chrome_options.add_argument('--disable-notifications'),
-    chrome_options.add_argument('--mute-audio'),
-    chrome_options.add_argument("-proxy-server='direct://"),
-    chrome_options.add_argument('--proxy-bypass-list=*'),
+    chrome_options.add_argument("--enable-automation"),
+    chrome_options.add_argument("--start-maximized"),
+    chrome_options.add_argument(f"--window-size={width},{height}"),
+    chrome_options.add_argument("--lang=en-GB"),
+    chrome_options.add_argument("--no-sandbox"),
+    chrome_options.add_argument("--disable-setuid-sandbox"),
+    chrome_options.add_argument("--disable-dev-shm-usage"),
+    chrome_options.add_argument("--disable-gpu"),
+    chrome_options.add_argument("--disable-accelerated-2d-canvas"),
+    chrome_options.add_argument("--disable-setuid-sandbox"),
+    chrome_options.add_argument("--disable-dev-shm-usage"),
+    chrome_options.add_argument("--proxy-server='direct://"),
+    chrome_options.add_argument("--proxy-bypass-list=*"),
+    chrome_options.add_argument("--allow-running-insecure-content"),
+    chrome_options.add_argument("--disable-web-security"),
+    chrome_options.add_argument("--disable-client-side-phishing-detection"),
+    chrome_options.add_argument("--disable-notifications"),
+    chrome_options.add_argument("--mute-audio"),
 
     # Disable downloads
     chrome_options.add_experimental_option(
